DROP VIEW IF EXISTS TRANSACTIONS_PAYEES_CATEGORIES;

DROP TABLE IF EXISTS transactions;

CREATE TABLE transactions (
  txId       INT            NOT NULL AUTO_INCREMENT PRIMARY KEY,
  payeeId    INT            NOT NULL,
  amount     DECIMAL(20, 2) NOT NULL,
  txType     VARCHAR(50)    NOT NULL,
  txStatus   VARCHAR(50)    NOT NULL,
  txDate     TIMESTAMP      NOT NULL,
  accountId  INT            NOT NULL,
  categoryId INT            NOT NULL
);

DROP TABLE IF EXISTS payees;

CREATE TABLE payees (
  payeeId    INT          NOT NULL AUTO_INCREMENT PRIMARY KEY,
  payee      VARCHAR(255) NOT NULL,
  categoryId INT          NOT NULL,
  address    VARCHAR(255) NOT NULL,
  city       VARCHAR(255) NOT NULL,
  state      VARCHAR(50)  NOT NULL,
  zip        VARCHAR(25)  NOT NULL,
  image      VARCHAR(255),
  motto      VARCHAR(512)
);

DROP TABLE IF EXISTS categories;

CREATE TABLE categories (
  categoryId   INT NOT NULL AUTO_INCREMENT PRIMARY KEY,
  categoryName VARCHAR(255)
);

DROP TABLE IF EXISTS accounts;

CREATE TABLE accounts (
  accountName   VARCHAR(255)   NOT NULL,
  accountId     INT            NOT NULL AUTO_INCREMENT PRIMARY KEY,
  accountType   INT            NOT NULL,
  accountNumber INT            NOT NULL,
  currentTotal  DECIMAL(20, 2) NOT NULL
);

CREATE OR REPLACE VIEW IF NOT EXISTS TRANSACTIONS_PAYEES_CATEGORIES AS
  SELECT TX.*, P.PAYEE, C.CATEGORYNAME
  FROM TRANSACTIONS TX, PAYEES P, CATEGORIES C
  WHERE TX.PAYEEID = P.PAYEEID
        AND TX.CATEGORYID = C.CATEGORYID;

INSERT INTO accounts (accountname, accountid, accounttype, accountnumber, currenttotal) VALUES ('Personal Savings Account',2,2,'1901220538',738.29);
INSERT INTO accounts (accountname, accountid, accounttype, accountnumber, currenttotal) VALUES ('Personal Checking Account',1,1,'0308051138',1765.72);

INSERT INTO categories (categoryname, categoryid) VALUES ('Automotive',1);
INSERT INTO categories (categoryname, categoryid) VALUES ('Beauty',2);
INSERT INTO categories (categoryname, categoryid) VALUES ('Clothing',3);
INSERT INTO categories (categoryname, categoryid) VALUES ('Electronics',4);
INSERT INTO categories (categoryname, categoryid) VALUES ('Food',5);
INSERT INTO categories (categoryname, categoryid) VALUES ('Games',6);
INSERT INTO categories (categoryname, categoryid) VALUES ('Grocery',7);
INSERT INTO categories (categoryname, categoryid) VALUES ('Health',8);
INSERT INTO categories (categoryname, categoryid) VALUES ('Housing',9);
INSERT INTO categories (categoryname, categoryid) VALUES ('Industrial',10);
INSERT INTO categories (categoryname, categoryid) VALUES ('Jewelry',11);
INSERT INTO categories (categoryname, categoryid) VALUES ('Kids',12);
INSERT INTO categories (categoryname, categoryid) VALUES ('Legal',13);
INSERT INTO categories (categoryname, categoryid) VALUES ('Medical',14);
INSERT INTO categories (categoryname, categoryid) VALUES ('Movies',15);
INSERT INTO categories (categoryname, categoryid) VALUES ('Music',16);
INSERT INTO categories (categoryname, categoryid) VALUES ('Outdoors',17);
INSERT INTO categories (categoryname, categoryid) VALUES ('Restaurants',18);
INSERT INTO categories (categoryname, categoryid) VALUES ('Salary',19);
INSERT INTO categories (categoryname, categoryid) VALUES ('Tools',20);
INSERT INTO categories (categoryname, categoryid) VALUES ('Toys',21);
INSERT INTO categories (categoryname, categoryid) VALUES ('Utilities',22);

INSERT INTO payees (payeeid, payee, categoryid, address, city, state, zip, image, motto) VALUES (1,'DCH Mortgages',9,'1285 Rezlog Plaza','Powhatan','RI','02212',NULL,NULL);
INSERT INTO payees (payeeid, payee, categoryid, address, city, state, zip, image, motto) VALUES (2,'Ill Communication Telephones',22,'1597 Figole Grove','Akron','OH','66345',NULL,NULL);
INSERT INTO payees (payeeid, payee, categoryid, address, city, state, zip, image, motto) VALUES (3,'Erol''s Internet',22,'453 Lomhab Junction','Kansas City','KS','60019',NULL,NULL);
INSERT INTO payees (payeeid, payee, categoryid, address, city, state, zip, image, motto) VALUES (4,'Acme Gas and Electric',22,'1669 Divided Court','Cheyenne','WY','48324',NULL,NULL);
INSERT INTO payees (payeeid, payee, categoryid, address, city, state, zip, image, motto) VALUES (5,'Happiness Gym',8,'1569 Falls Rd.','Baltimore','MD','95306',NULL,NULL);
INSERT INTO payees (payeeid, payee, categoryid, address, city, state, zip, image, motto) VALUES (6,'Shop-Rite Grocery Store',5,'311 St. Paul Ave.','Baltimore','MD','08697',NULL,NULL);
INSERT INTO payees (payeeid, payee, categoryid, address, city, state, zip, image, motto) VALUES (7,'Sushi Land',18,'808 Calvert St.','Baltimore','MD','01848',NULL,NULL);
INSERT INTO payees (payeeid, payee, categoryid, address, city, state, zip, image, motto) VALUES (8,'Worthless Peon Productions',19,'125 Scrub Street','Santa Monica','CA','90111',NULL,NULL);
INSERT INTO payees (payeeid, payee, categoryid, address, city, state, zip, image, motto) VALUES (9,'The CX Institute',19,'1715 Greymalkin Lane','Westchester','NY','10047',NULL,NULL);
INSERT INTO payees (payeeid, payee, categoryid, address, city, state, zip, image, motto) VALUES (10,'Gleichner, Lind and Olson, Ltd.',17,'142 Wune Street','Deetelu','WV','80587','/images/animals/9.jpg','Optimized executive frame');
INSERT INTO payees (payeeid, payee, categoryid, address, city, state, zip, image, motto) VALUES (11,'Bradtke Brothers, Grocers',7,'1076 Dedza Ridge','Mogekheh','GA','24242','/images/business/10.jpg','Proactive local function');
INSERT INTO payees (payeeid, payee, categoryid, address, city, state, zip, image, motto) VALUES (12,'Klein Cars',1,'1939 Rolfs Pass','Baltiimore','MD','97394','/images/technics/4.jpg','Seamless heuristic process improvement');
INSERT INTO payees (payeeid, payee, categoryid, address, city, state, zip, image, motto) VALUES (13,'Russel Group',20,'218 Utba Terrace','Kapasaw','MA','50773','/images/technics/4.jpg','Cloned impactful open system');
INSERT INTO payees (payeeid, payee, categoryid, address, city, state, zip, image, motto) VALUES (14,'Mitchell-Sporer',6,'1249 Hisog Place','Zincote','MD','76421','/images/nature/8.jpg','Face to face local collaboration');
INSERT INTO payees (payeeid, payee, categoryid, address, city, state, zip, image, motto) VALUES (15,'Kerluke Amusements',21,'1729 Bozoz Mill','Little Rock','AR','56053','/images/cats/4.jpg','Phased reciprocal product');
INSERT INTO payees (payeeid, payee, categoryid, address, city, state, zip, image, motto) VALUES (16,'Spinka Salon',2,'857 Givce Turnpike','Palomar','CA','99533','/images/cats/10.jpg','Monitored encompassing workforce');
INSERT INTO payees (payeeid, payee, categoryid, address, city, state, zip, image, motto) VALUES (17,'Bauch-Stehr Medical Partners',8,'671 York Ave','Baltimore','MD','54952','/images/business/3.jpg','Versatile optimizing support');
INSERT INTO payees (payeeid, payee, categoryid, address, city, state, zip, image, motto) VALUES (18,'Legros, Trantow and Kub',4,'1189 Tele Highway','Boothbay','ME','14298','/images/business/3.jpg','Future-proofed analyzing frame');
INSERT INTO payees (payeeid, payee, categoryid, address, city, state, zip, image, motto) VALUES (19,'The Senator Theater',15,'1689 North York Rd','Baltimore','MD','48693','/images/business/5.jpg','Yesterday''s movies tomorrow');
INSERT INTO payees (payeeid, payee, categoryid, address, city, state, zip, image, motto) VALUES (20,'Zieme & Ratke, Pediatrics',14,'1873 Razif Loop','Fonzopo','FL','55902','/images/business/2.jpg','Multi-lateral grid-enabled toolset');
INSERT INTO payees (payeeid, payee, categoryid, address, city, state, zip, image, motto) VALUES (21,'Prosacco Day Care',12,'503 Fotef Square','Towson','MD','91797','/images/transport/6.jpg','User-friendly bottom-line hardware');
INSERT INTO payees (payeeid, payee, categoryid, address, city, state, zip, image, motto) VALUES (22,'Heathcote Inc',3,'798 Defaj Point','Tajuwbi','WI','88464','/images/business/3.jpg','Secured web-enabled Graphical Clothing Interface');
INSERT INTO payees (payeeid, payee, categoryid, address, city, state, zip, image, motto) VALUES (23,'Davis, Muller and Marvin',21,'319 Nazmo Road','Sohcutzeh','VT','09725','/images/technics/1.jpg','Persevering regional moratorium');
INSERT INTO payees (payeeid, payee, categoryid, address, city, state, zip, image, motto) VALUES (24,'Boehm, Bernhard and Lebsack',16,'1146 Kubo Parkway','Lohsunru','OH','17404','/images/nature/3.jpg','Function-based logistical paradigm');
INSERT INTO payees (payeeid, payee, categoryid, address, city, state, zip, image, motto) VALUES (25,'Kohler, Runolfsdottir and Torp',11,'841 Pewuj Court','Nesetvuv','NY','86629','/images/technics/7.jpg','Diverse optimizing paradigm');
INSERT INTO payees (payeeid, payee, categoryid, address, city, state, zip, image, motto) VALUES (26,'Hill-Harvey',21,'858 Pekcip Parkway','Olawozpo','NH','12246','/images/cats/3.jpg','Synchronised systemic internet solution');
INSERT INTO payees (payeeid, payee, categoryid, address, city, state, zip, image, motto) VALUES (27,'Deckow-Hand',10,'1622 Avena Circle','Nuebaheh','MA','52038','/images/animals/9.jpg','Cloned directional attitude');
INSERT INTO payees (payeeid, payee, categoryid, address, city, state, zip, image, motto) VALUES (28,'Veum Industrial Products',10,'587 Ipobak Terrace','Majfazme','CT','16097','/images/nature/6.jpg','Operative maximized matrices');
INSERT INTO payees (payeeid, payee, categoryid, address, city, state, zip, image, motto) VALUES (29,'Watsica Design',10,'289 Vaewi Avenue','Dorgaec','WY','19966','/images/business/5.jpg','Streamlined full-range budgetary management');
INSERT INTO payees (payeeid, payee, categoryid, address, city, state, zip, image, motto) VALUES (32,'The Wolf and Tortoise',18,'1939 Hetuv Pass','Sekawce','AK','97394','/images/technics/4.jpg','Seamless heuristic process improvement');
INSERT INTO payees (payeeid, payee, categoryid, address, city, state, zip, image, motto) VALUES (35,'Bauch Opicians',14,'1729 Bozoz Mill','Jirepovo','AR','56053','/images/cats/4.jpg','Phased reciprocal product');
INSERT INTO payees (payeeid, payee, categoryid, address, city, state, zip, image, motto) VALUES (38,'Legos, Legos, Legos',21,'1189 Tele Highway','Obcibadi','ME','14298','/images/business/3.jpg','Future-proofed analyzing frame');
INSERT INTO payees (payeeid, payee, categoryid, address, city, state, zip, image, motto) VALUES (39,'Rau, Kertzmann and Cremin',15,'1689 Kefoz Plaza','Podmowed','MD','48693','/images/business/5.jpg','Grass-roots composite infrastructure');
INSERT INTO payees (payeeid, payee, categoryid, address, city, state, zip, image, motto) VALUES (40,'Quigley''s Steaks',18,'1873 Razif Loop','Fonozpo','FL','55902','/images/business/2.jpg','Multi-lateral grid-enabled toolset');
INSERT INTO payees (payeeid, payee, categoryid, address, city, state, zip, image, motto) VALUES (43,'Wayne Enterprises',10,'319 Thomas Wayne Road','Gotham','NY','10939','/images/technics/1.jpg','Persevering regional moratorium');
INSERT INTO payees (payeeid, payee, categoryid, address, city, state, zip, image, motto) VALUES (44,'Stark Electronics',4,'1146 Kubo Parkway','Cupertino','CA','96412','/images/nature/3.jpg','Function-based logistical paradigm');
INSERT INTO payees (payeeid, payee, categoryid, address, city, state, zip, image, motto) VALUES (45,'Tyrell Corporation',19,'841 Pewuj Court','Netseyev','NY','86629','/images/technics/7.jpg','Diverse optimizing paradigm');
INSERT INTO payees (payeeid, payee, categoryid, address, city, state, zip, image, motto) VALUES (46,'Yoyodyne Propulsion Systems',10,'16 Blue Blazer Way','Grover''s Mill','NK','07561','/images/cats/3.jpg','Synchronised systemic internet solution');
INSERT INTO payees (payeeid, payee, categoryid, address, city, state, zip, image, motto) VALUES (47,'Goodman, Lieber, Kurtzberg, Holliway',13,'16 W 12 St.','New York','NY','10015','/images/animals/9.jpg',NULL);
INSERT INTO payees (payeeid, payee, categoryid, address, city, state, zip, image, motto) VALUES (48,'Rodriguez Computing',4,'587 Ipobak Terrace','Majfazme','CT','16097','/images/nature/6.jpg','Operative maximized matrices');
INSERT INTO payees (payeeid, payee, categoryid, address, city, state, zip, image, motto) VALUES (49,'Tower Shields',10,'289 Vaewi Avenue','Dorkachek','WY','19966','/images/business/5.jpg','Streamlined full-range budgetary management');

INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (1,17,-97.74,'Debit','Cleared','2015-01-04T23:50:19.938',1,8);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (2,17,-68.91,'Debit','Cleared','2015-05-06T20:48:50.504',1,8);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (3,17,-94.58,'Debit','Cleared','2015-07-19T16:22:56.498',1,8);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (4,17,-57.24,'Debit','Cleared','2015-11-28T11:55:44.790',1,8);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (5,6,-52.44,'Debit','Cleared','2015-01-03T23:42:56.709',1,5);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (6,6,-85.11,'Debit','Cleared','2015-01-14T02:24:15.225',1,5);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (7,6,-61.09,'Debit','Cleared','2015-01-16T11:24:42.123',1,5);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (8,6,-63.76,'Debit','Cleared','2015-01-23T06:32:34.844',1,5);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (9,8,2000,'Credit','Cleared','2015-01-01T07:24:02.995',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (10,8,2000,'Credit','Cleared','2015-01-07T12:20:55.267',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (11,9,2000,'Credit','Cleared','2015-01-12T00:29:39.489',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (12,9,2000,'Credit','Cleared','2015-01-17T18:05:03.733',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (13,43,-85.17,'Debit','Cleared','2015-01-06T18:15:50.529',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (14,20,-90.54,'Debit','Cleared','2015-01-19T01:42:36.951',1,14);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (15,22,-72.61,'Auto-Pay','Cleared','2015-01-23T02:15:34.336',1,3);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (16,15,-64.65,'Debit','Cleared','2015-01-29T18:45:17.658',1,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (17,27,-49.97,'Debit','Cleared','2015-01-12T00:25:17.607',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (18,22,-94.53,'Auto-Pay','Cleared','2015-01-22T11:36:19.598',1,3);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (19,19,-16.64,'Debit','Cleared','2015-01-15T08:05:39.541',1,15);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (20,10,-92.69,'Debit','Cleared','2015-01-10T08:25:03.917',1,17);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (21,32,-77.53,'Debit','Cleared','2015-01-10T05:21:40.483',2,18);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (22,28,-38.77,'Debit','Cleared','2015-01-23T00:31:48.071',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (23,22,-13.79,'Auto-Pay','Cleared','2015-01-16T13:50:06.934',1,3);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (24,19,-72.4,'Debit','Cleared','2015-01-01T23:15:29.052',1,15);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (25,39,-40.54,'Debit','Cleared','2015-01-24T00:31:54.304',1,15);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (26,23,-76.86,'Debit','Cleared','2015-01-16T20:23:22.875',2,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (27,14,-17.7,'Debit','Cleared','2015-01-16T02:55:20.743',1,6);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (28,44,-17.21,'Debit','Cleared','2015-01-03T16:18:57.779',1,4);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (29,46,-71.42,'Debit','Cleared','2015-01-12T05:04:50.393',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (30,28,-31.79,'Debit','Cleared','2015-01-27T19:10:52.573',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (31,48,-75.27,'Debit','Cleared','2015-01-24T21:04:31.285',1,4);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (32,23,-34.25,'Debit','Cleared','2015-01-10T20:31:42.097',2,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (33,35,-71.61,'Debit','Cleared','2015-01-20T11:42:07.502',1,14);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (34,10,-61.07,'Debit','Cleared','2015-01-21T04:31:07.688',1,17);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (35,43,-44.03,'Debit','Cleared','2015-01-06T02:10:31.329',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (36,44,-51.76,'Debit','Cleared','2015-01-18T14:47:47.540',1,4);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (37,18,-69.63,'Debit','Cleared','2015-01-21T23:38:05.770',1,4);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (38,20,-70.38,'Debit','Cleared','2015-01-22T11:01:08.555',1,14);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (39,26,-82.66,'Debit','Cleared','2015-01-16T01:27:49.917',1,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (40,28,-44,'Debit','Cleared','2015-01-12T07:48:00.051',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (41,12,-21.61,'Debit','Cleared','2015-01-05T20:00:04.587',1,1);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (42,15,-53.25,'Debit','Cleared','2015-01-19T01:41:50.662',1,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (43,14,-45.01,'Debit','Cleared','2015-01-06T11:53:19.188',1,6);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (44,20,-10.16,'Debit','Cleared','2015-01-31T09:42:43.250',1,14);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (45,18,-83.51,'Debit','Cleared','2015-01-27T13:12:45.663',1,4);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (46,15,-46.12,'Debit','Cleared','2015-01-30T02:41:45.300',1,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (47,39,-94.26,'Debit','Cleared','2015-01-23T22:27:56.376',1,15);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (48,48,-96.16,'Debit','Cleared','2015-01-29T23:11:35.301',1,4);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (49,35,-40.35,'Debit','Cleared','2015-01-08T15:18:49.918',1,14);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (50,20,-58.61,'Debit','Cleared','2015-01-08T12:25:13.553',1,14);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (51,19,-91.24,'Debit','Cleared','2015-01-04T13:40:12.079',1,15);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (52,20,-75.15,'Debit','Cleared','2015-01-18T00:10:33.648',1,14);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (53,47,-75.5,'Withdrawal','Cleared','2015-01-29T16:44:08.113',2,13);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (54,15,-21,'Debit','Cleared','2015-01-24T03:07:34.787',1,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (55,49,-41.29,'Debit','Cleared','2015-01-12T01:54:12.172',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (56,21,-84.12,'Debit','Cleared','2015-01-27T22:55:32.914',1,12);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (57,25,-31.57,'Debit','Cleared','2015-01-04T00:18:59.670',1,11);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (58,44,-23.53,'Debit','Cleared','2015-01-30T11:30:03.022',1,4);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (59,19,-34.29,'Debit','Cleared','2015-01-26T05:23:08.812',1,15);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (60,24,-37.28,'Debit','Cleared','2015-01-18T13:11:41.306',1,16);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (61,18,-66.25,'Debit','Cleared','2015-01-26T18:04:45.981',1,4);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (62,47,-93.26,'Withdrawal','Cleared','2015-01-14T05:03:54.399',2,13);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (63,11,-50.96,'Auto-Pay','Cleared','2015-01-10T22:17:48.472',1,7);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (64,28,-88.7,'Debit','Cleared','2015-01-25T17:50:19.323',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (65,15,-56.95,'Debit','Cleared','2015-01-21T23:45:36.271',1,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (66,12,-19.22,'Debit','Cleared','2015-01-28T12:46:32.108',1,1);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (67,38,-93.27,'Debit','Cleared','2015-01-09T06:05:36.363',1,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (68,21,-66.61,'Debit','Cleared','2015-01-30T23:25:02.492',1,12);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (69,19,-6.62,'Debit','Cleared','2015-01-19T07:17:55.155',1,15);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (70,32,-20.25,'Debit','Cleared','2015-01-19T00:19:52.788',2,18);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (71,6,-62.08,'Debit','Cleared','2015-02-07T21:13:17.891',1,5);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (72,6,-59.07,'Debit','Cleared','2015-02-08T06:12:37.087',1,5);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (73,6,-95.49,'Debit','Cleared','2015-02-16T00:18:23.805',1,5);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (74,6,-64.5,'Debit','Cleared','2015-02-28T22:51:03.666',1,5);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (75,8,2000,'Credit','Cleared','2015-02-06T05:56:34.211',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (76,8,2000,'Credit','Cleared','2015-02-17T23:10:07.987',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (77,9,2000,'Credit','Cleared','2015-02-04T02:14:26.746',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (78,9,2000,'Credit','Cleared','2015-02-15T15:47:11.595',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (79,45,1500,'Deposit','Cleared','2015-02-10T07:39:27.327',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (80,45,1500,'Deposit','Cleared','2015-02-24T21:39:10.788',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (81,19,-25.82,'Debit','Cleared','2015-02-06T01:15:32.606',1,15);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (82,27,-52.7,'Debit','Cleared','2015-02-11T15:47:51.146',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (83,45,1500,'Deposit','Cleared','2015-02-10T09:34:32.178',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (84,13,-23.2,'Debit','Cleared','2015-02-26T05:42:55.183',1,20);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (85,26,-58.14,'Debit','Cleared','2015-02-26T11:23:56.382',1,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (86,19,-56.12,'Debit','Cleared','2015-02-15T06:20:06.440',1,15);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (87,38,-20.51,'Debit','Cleared','2015-02-08T02:26:14.184',1,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (88,29,-72.35,'Debit','Cleared','2015-02-11T07:31:31.301',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (89,21,-7.89,'Debit','Cleared','2015-02-25T18:25:16.153',1,12);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (90,12,-51.54,'Debit','Cleared','2015-02-11T02:25:50.332',1,1);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (91,22,-91.39,'Auto-Pay','Cleared','2015-02-05T10:07:23.352',1,3);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (92,11,-47.86,'Auto-Pay','Cleared','2015-02-23T10:07:02.118',1,7);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (93,28,-19.86,'Debit','Cleared','2015-02-24T07:16:14.037',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (94,35,-49.36,'Debit','Cleared','2015-02-20T17:35:57.930',1,14);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (95,40,-62.92,'Auto-Pay','Cleared','2015-02-11T12:42:38.161',2,18);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (96,43,-70.89,'Debit','Cleared','2015-02-11T23:03:58.269',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (97,20,-91.41,'Debit','Cleared','2015-02-06T10:56:05.651',1,14);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (98,16,-12.99,'Debit','Cleared','2015-02-08T10:29:00.495',1,2);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (99,11,-63.67,'Auto-Pay','Cleared','2015-02-26T22:46:20.511',1,7);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (100,28,-28.43,'Debit','Cleared','2015-02-17T12:58:04.974',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (101,47,-17.38,'Withdrawal','Cleared','2015-02-22T20:48:09.812',2,13);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (102,14,-53.53,'Debit','Cleared','2015-02-23T23:37:03.191',1,6);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (103,26,-51.28,'Debit','Cleared','2015-02-10T20:00:13.670',1,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (104,45,1500,'Deposit','Cleared','2015-02-25T09:21:07.384',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (105,28,-90.53,'Debit','Cleared','2015-02-20T15:56:01.570',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (106,16,-22.33,'Debit','Cleared','2015-02-06T06:20:05.874',1,2);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (107,13,-20.01,'Debit','Cleared','2015-02-20T12:48:19.618',1,20);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (108,12,-47.82,'Debit','Cleared','2015-02-17T00:04:13.936',1,1);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (109,22,-39.13,'Auto-Pay','Cleared','2015-02-03T14:51:40.823',1,3);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (110,28,-73.67,'Debit','Cleared','2015-02-28T23:51:42.364',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (111,26,-15.06,'Debit','Cleared','2015-02-09T06:04:25.755',1,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (112,10,-28.39,'Debit','Cleared','2015-02-03T15:59:06.916',1,17);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (113,13,-26.26,'Debit','Cleared','2015-02-02T19:52:51.181',1,20);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (114,27,-87.79,'Debit','Cleared','2015-02-17T09:41:51.055',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (115,11,-81.07,'Auto-Pay','Cleared','2015-02-27T05:42:46.741',1,7);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (116,20,-46.93,'Debit','Cleared','2015-02-04T05:26:31.914',1,14);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (117,26,-62.53,'Debit','Cleared','2015-02-03T07:58:23.483',1,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (118,38,-81.7,'Debit','Cleared','2015-02-12T21:16:26.740',1,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (119,40,-84.26,'Auto-Pay','Cleared','2015-02-18T15:42:20.362',2,18);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (120,15,-83.36,'Debit','Cleared','2015-02-19T17:32:00.601',1,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (121,46,-49.62,'Debit','Cleared','2015-02-26T04:19:46.139',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (122,39,-79.92,'Debit','Cleared','2015-02-24T19:47:01.614',1,15);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (123,44,-95.04,'Debit','Cleared','2015-02-19T19:01:46.326',1,4);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (124,44,-58.68,'Debit','Cleared','2015-02-06T19:13:28.989',1,4);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (125,43,-17.32,'Debit','Cleared','2015-02-27T04:27:39.193',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (126,35,-76.61,'Debit','Cleared','2015-02-08T06:08:14.200',1,14);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (127,22,-56.77,'Auto-Pay','Cleared','2015-02-10T18:49:01.328',1,3);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (128,25,-8.73,'Debit','Cleared','2015-02-05T07:16:40.605',1,11);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (129,13,-61.68,'Debit','Cleared','2015-02-17T18:00:55.493',1,20);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (130,25,-92.64,'Debit','Cleared','2015-02-02T19:20:49.437',1,11);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (131,6,-57.62,'Debit','Cleared','2015-03-05T03:17:48.094',1,5);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (132,6,-97.27,'Debit','Cleared','2015-03-11T18:10:51.085',1,5);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (133,6,-66.11,'Debit','Cleared','2015-03-17T23:29:04.629',1,5);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (134,6,-97.9,'Debit','Cleared','2015-03-25T10:56:01.681',1,5);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (135,8,2000,'Credit','Cleared','2015-03-03T02:12:45.606',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (136,8,2000,'Credit','Cleared','2015-03-09T08:23:47.911',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (137,9,2000,'Credit','Cleared','2015-03-06T20:45:18.069',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (138,9,2000,'Credit','Cleared','2015-03-09T07:22:33.859',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (139,29,-9.04,'Debit','Cleared','2015-03-02T23:17:33.714',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (140,22,-71.36,'Auto-Pay','Cleared','2015-03-22T09:49:19.519',1,3);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (141,38,-20.45,'Debit','Cleared','2015-03-05T11:00:54.162',1,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (142,46,-54.04,'Debit','Cleared','2015-03-17T11:59:53.258',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (143,29,-81.99,'Debit','Cleared','2015-03-22T13:14:52.175',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (144,26,-73.4,'Debit','Cleared','2015-03-31T14:44:50.663',1,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (145,49,-17.7,'Debit','Cleared','2015-03-23T08:10:48.915',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (146,11,-84.1,'Auto-Pay','Cleared','2015-03-23T14:08:02.916',1,7);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (147,16,-77.53,'Debit','Cleared','2015-03-22T23:45:23.995',1,2);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (148,10,-55.19,'Debit','Cleared','2015-03-10T19:41:22.731',1,17);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (149,19,-46.15,'Debit','Cleared','2015-03-27T22:09:36.456',1,15);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (150,46,-86.1,'Debit','Cleared','2015-03-05T05:46:54.388',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (151,21,-95.56,'Debit','Cleared','2015-03-12T17:24:59.778',1,12);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (152,22,-28.55,'Auto-Pay','Cleared','2015-03-16T20:26:10.198',1,3);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (153,39,-54.81,'Debit','Cleared','2015-03-20T23:32:59.465',1,15);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (154,10,-66.9,'Debit','Cleared','2015-03-16T14:11:41.703',1,17);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (155,48,-83.07,'Debit','Cleared','2015-03-10T22:08:38.498',1,4);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (156,21,-59.5,'Debit','Cleared','2015-03-23T11:24:58.945',1,12);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (157,47,-17.34,'Withdrawal','Cleared','2015-03-10T13:35:05.815',2,13);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (158,46,-88.68,'Debit','Cleared','2015-03-07T15:05:11.204',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (159,43,-41.22,'Debit','Cleared','2015-03-25T03:06:15.847',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (160,32,-49.24,'Debit','Cleared','2015-03-20T13:02:23.847',2,18);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (161,40,-97.34,'Auto-Pay','Cleared','2015-03-07T16:55:23.167',2,18);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (162,15,-63.63,'Debit','Cleared','2015-03-29T16:10:48.644',1,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (163,27,-62.97,'Debit','Cleared','2015-03-25T00:50:34.173',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (164,11,-54.98,'Auto-Pay','Cleared','2015-03-28T21:50:53.352',1,7);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (165,45,1500,'Deposit','Cleared','2015-03-24T11:46:54.936',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (166,43,-39.89,'Debit','Cleared','2015-03-29T05:57:42.382',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (167,48,-20.89,'Debit','Cleared','2015-03-22T07:36:22.891',1,4);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (168,45,1500,'Deposit','Cleared','2015-03-14T19:11:55.224',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (169,15,-35.22,'Debit','Cleared','2015-03-15T05:26:06.969',1,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (170,27,-89.04,'Debit','Cleared','2015-03-27T12:38:13.407',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (171,13,-62.43,'Debit','Cleared','2015-03-09T09:25:26.894',1,20);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (172,11,-46.23,'Auto-Pay','Cleared','2015-03-24T04:51:55.815',1,7);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (173,46,-8.19,'Debit','Cleared','2015-03-22T18:06:23.865',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (174,21,-77.98,'Debit','Cleared','2015-03-04T00:37:48.008',1,12);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (175,12,-32.78,'Debit','Cleared','2015-03-02T00:01:53.528',1,1);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (176,38,-52.23,'Debit','Cleared','2015-03-22T14:19:41.947',1,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (177,44,-61.08,'Debit','Cleared','2015-03-30T08:58:19.589',1,4);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (178,27,-70.1,'Debit','Cleared','2015-03-01T19:48:45.642',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (179,45,1500,'Deposit','Cleared','2015-03-06T21:30:33.044',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (180,22,-49.58,'Auto-Pay','Cleared','2015-03-07T04:52:54.563',1,3);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (181,40,-98.12,'Auto-Pay','Cleared','2015-03-19T23:13:30.029',2,18);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (182,40,-52.69,'Auto-Pay','Cleared','2015-03-23T13:31:20.899',2,18);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (183,18,-67.16,'Debit','Cleared','2015-03-14T00:41:21.138',1,4);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (184,29,-40.95,'Debit','Cleared','2015-03-24T06:57:23.301',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (185,28,-57.83,'Debit','Cleared','2015-03-10T16:51:27.368',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (186,11,-86.34,'Auto-Pay','Cleared','2015-03-10T20:03:33.940',1,7);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (187,44,-71.69,'Debit','Cleared','2015-03-22T17:46:33.942',1,4);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (188,27,-55.49,'Debit','Cleared','2015-03-10T22:53:57.653',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (189,20,-79.59,'Debit','Cleared','2015-03-22T16:37:42.731',1,14);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (190,48,-37.01,'Debit','Cleared','2015-03-09T00:59:58.461',1,4);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (191,12,-29.2,'Debit','Cleared','2015-03-07T04:46:37.143',1,1);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (192,27,-60.8,'Debit','Cleared','2015-03-04T12:31:31.711',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (193,32,-64.99,'Debit','Cleared','2015-03-31T02:46:11.632',2,18);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (194,25,-35.4,'Debit','Cleared','2015-03-12T04:48:48.860',1,11);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (195,39,-36.87,'Debit','Cleared','2015-03-21T04:53:17.606',1,15);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (196,24,-68.73,'Debit','Cleared','2015-03-05T15:37:51.317',1,16);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (197,11,-77.64,'Auto-Pay','Cleared','2015-03-20T03:06:00.732',1,7);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (198,46,-15.73,'Debit','Cleared','2015-03-22T12:38:10.180',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (199,13,-39.93,'Debit','Cleared','2015-03-18T06:20:01.207',1,20);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (200,13,-9.29,'Debit','Cleared','2015-03-16T18:36:14.359',1,20);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (201,6,-88.8,'Debit','Cleared','2015-04-02T08:28:15.956',1,5);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (202,6,-75.62,'Debit','Cleared','2015-04-14T19:55:10.721',1,5);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (203,6,-63.76,'Debit','Cleared','2015-04-15T14:54:40.828',1,5);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (204,6,-83.76,'Debit','Cleared','2015-04-28T19:40:59.759',1,5);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (205,8,2000,'Credit','Cleared','2015-04-08T01:23:10.111',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (206,8,2000,'Credit','Cleared','2015-04-14T22:59:19.706',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (207,9,2000,'Credit','Cleared','2015-04-01T07:47:21.887',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (208,9,2000,'Credit','Cleared','2015-04-03T01:18:12.426',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (209,43,-54.56,'Debit','Cleared','2015-04-28T16:15:21.094',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (210,47,-48.07,'Withdrawal','Cleared','2015-04-29T10:31:47.186',2,13);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (211,44,-44.28,'Debit','Cleared','2015-04-04T21:10:18.307',1,4);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (212,22,-46.41,'Auto-Pay','Cleared','2015-04-08T22:04:30.290',1,3);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (213,24,-33.38,'Debit','Cleared','2015-04-06T18:51:35.148',1,16);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (214,16,-28.42,'Debit','Cleared','2015-04-21T09:17:19.859',1,2);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (215,45,1500,'Deposit','Cleared','2015-04-30T04:05:15.387',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (216,13,-59.07,'Debit','Cleared','2015-04-16T19:10:50.893',1,20);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (217,39,-11.12,'Debit','Cleared','2015-04-25T16:01:20.307',1,15);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (218,35,-54.89,'Debit','Cleared','2015-04-14T08:28:32.446',1,14);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (219,15,-69.36,'Debit','Cleared','2015-04-23T10:33:53.426',1,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (220,44,-99.28,'Debit','Cleared','2015-04-02T04:03:15.488',1,4);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (221,13,-94.3,'Debit','Cleared','2015-04-04T06:46:43.052',1,20);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (222,14,-13.96,'Debit','Cleared','2015-04-20T04:48:08.217',1,6);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (223,10,-47.86,'Debit','Cleared','2015-04-12T23:41:39.759',1,17);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (224,24,-69.78,'Debit','Cleared','2015-04-22T20:49:46.403',1,16);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (225,40,-85.05,'Auto-Pay','Cleared','2015-04-30T05:28:52.417',2,18);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (226,38,-10.4,'Debit','Cleared','2015-04-29T23:05:54.773',1,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (227,44,-89.85,'Debit','Cleared','2015-04-21T16:56:20.450',1,4);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (228,26,-19.28,'Debit','Cleared','2015-04-04T06:47:20.823',1,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (229,35,-89.24,'Debit','Cleared','2015-04-26T14:33:12.717',1,14);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (230,25,-74.49,'Debit','Cleared','2015-04-23T12:37:11.572',1,11);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (231,23,-48.63,'Debit','Cleared','2015-04-30T15:09:00.504',2,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (232,38,-19.48,'Debit','Cleared','2015-04-26T11:34:44.796',1,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (233,35,-29.67,'Debit','Cleared','2015-04-28T06:25:54.842',1,14);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (234,20,-80.7,'Debit','Cleared','2015-04-26T04:02:34.305',1,14);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (235,44,-96.51,'Debit','Cleared','2015-04-11T01:58:25.067',1,4);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (236,27,-76.43,'Debit','Cleared','2015-04-26T17:34:55.096',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (237,47,-83.77,'Withdrawal','Cleared','2015-04-26T06:50:16.557',2,13);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (238,46,-27.48,'Debit','Cleared','2015-04-01T13:53:21.045',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (239,43,-44.4,'Debit','Cleared','2015-04-19T00:45:32.917',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (240,13,-20.65,'Debit','Cleared','2015-04-12T21:21:36.195',1,20);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (241,40,-45.33,'Auto-Pay','Cleared','2015-04-06T12:09:19.170',2,18);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (242,35,-66.51,'Debit','Cleared','2015-04-12T09:44:34.067',1,14);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (243,48,-18.15,'Debit','Cleared','2015-04-29T03:51:42.098',1,4);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (244,25,-70.21,'Debit','Cleared','2015-04-22T20:54:56.797',1,11);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (245,47,-21.21,'Withdrawal','Cleared','2015-04-06T13:19:39.891',2,13);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (246,43,-52.45,'Debit','Cleared','2015-04-04T21:13:01.084',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (247,23,-43.74,'Debit','Cleared','2015-04-11T18:49:44.974',2,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (248,13,-54.61,'Debit','Cleared','2015-04-26T19:07:31.551',1,20);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (249,22,-21.84,'Auto-Pay','Cleared','2015-04-27T19:12:40.374',1,3);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (250,40,-53.7,'Auto-Pay','Cleared','2015-04-16T04:16:59.866',2,18);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (251,20,-23.54,'Debit','Cleared','2015-04-06T02:12:07.198',1,14);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (252,18,-68.1,'Debit','Cleared','2015-04-27T15:41:17.939',1,4);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (253,19,-82.93,'Debit','Cleared','2015-04-14T18:49:19.442',1,15);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (254,35,-92.41,'Debit','Cleared','2015-04-29T12:39:26.216',1,14);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (255,6,-58.15,'Debit','Cleared','2015-05-07T21:47:55.311',1,5);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (256,6,-73.46,'Debit','Cleared','2015-05-14T05:33:27.355',1,5);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (257,6,-94.14,'Debit','Cleared','2015-05-18T10:04:59.260',1,5);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (258,6,-55.5,'Debit','Cleared','2015-05-24T09:34:50.461',1,5);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (259,8,2000,'Credit','Cleared','2015-05-10T16:48:23.689',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (260,8,2000,'Credit','Cleared','2015-05-14T02:20:22.387',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (261,9,2000,'Credit','Cleared','2015-05-12T18:12:51.673',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (262,9,2000,'Credit','Cleared','2015-05-20T01:34:10.341',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (263,13,-96.15,'Debit','Cleared','2015-05-28T11:52:47.920',1,20);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (264,43,-97.75,'Debit','Cleared','2015-05-20T05:59:26.368',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (265,47,-42.12,'Withdrawal','Cleared','2015-05-02T19:56:57.401',2,13);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (266,35,-69.88,'Debit','Cleared','2015-05-28T09:50:47.170',1,14);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (267,16,-48.58,'Debit','Cleared','2015-05-17T01:14:10.395',1,2);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (268,43,-61.43,'Debit','Cleared','2015-05-02T12:16:17.619',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (269,24,-53.13,'Debit','Cleared','2015-05-08T19:11:24.943',1,16);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (270,47,-20.81,'Withdrawal','Cleared','2015-05-13T08:32:51.411',2,13);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (271,13,-29.29,'Debit','Cleared','2015-05-04T01:46:56.973',1,20);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (272,45,1500,'Deposit','Cleared','2015-05-26T09:08:31.272',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (273,46,-82.68,'Debit','Cleared','2015-05-03T06:40:51.841',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (274,29,-93.34,'Debit','Cleared','2015-05-22T06:51:03.466',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (275,20,-75.49,'Debit','Cleared','2015-05-11T07:41:30.183',1,14);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (276,46,-70.71,'Debit','Cleared','2015-05-29T22:47:51.713',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (277,26,-43.77,'Debit','Cleared','2015-05-08T21:32:39.567',1,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (278,10,-82.88,'Debit','Cleared','2015-05-23T22:22:51.364',1,17);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (279,18,-71.71,'Debit','Cleared','2015-05-26T00:17:53.773',1,4);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (280,19,-56.1,'Debit','Cleared','2015-05-26T00:22:48.963',1,15);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (281,46,-97.94,'Debit','Cleared','2015-05-28T21:54:00.701',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (282,40,-35.69,'Auto-Pay','Cleared','2015-05-03T09:25:23.460',2,18);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (283,32,-45.12,'Debit','Cleared','2015-05-02T10:32:24.041',2,18);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (284,15,-73.67,'Debit','Cleared','2015-05-01T17:17:51.638',1,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (285,26,-81.47,'Debit','Cleared','2015-05-19T09:59:19.115',1,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (286,16,-58.15,'Debit','Cleared','2015-05-06T22:38:47.059',1,2);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (287,49,-53.85,'Debit','Cleared','2015-05-14T17:30:37.289',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (288,32,-62.93,'Debit','Cleared','2015-05-23T03:08:45.231',2,18);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (289,18,-85.04,'Debit','Cleared','2015-05-19T00:10:38.475',1,4);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (290,21,-38.04,'Debit','Cleared','2015-06-01T02:39:21.747',1,12);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (291,21,-41.35,'Debit','Cleared','2015-05-20T07:20:11.796',1,12);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (292,24,-56.14,'Debit','Cleared','2015-05-29T23:26:40.711',1,16);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (293,32,-7.23,'Debit','Cleared','2015-05-26T05:04:34.257',2,18);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (294,10,-91.36,'Debit','Cleared','2015-05-30T09:55:22.631',1,17);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (295,16,-58.12,'Debit','Cleared','2015-05-23T20:22:32.519',1,2);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (296,10,-77.15,'Debit','Cleared','2015-05-29T16:10:29.947',1,17);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (297,32,-43.91,'Debit','Cleared','2015-05-04T22:47:47.601',2,18);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (298,47,-11.33,'Withdrawal','Cleared','2015-05-28T09:34:52.247',2,13);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (299,46,-99.18,'Debit','Cleared','2015-05-19T07:14:59.589',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (300,46,-41.51,'Debit','Cleared','2015-05-07T23:02:54.285',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (301,38,-53.03,'Debit','Cleared','2015-05-08T08:10:43.858',1,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (302,32,-92.64,'Debit','Cleared','2015-05-29T14:48:15.741',2,18);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (303,20,-19.55,'Debit','Cleared','2015-05-19T02:32:22.655',1,14);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (304,32,-24.2,'Debit','Cleared','2015-05-19T16:30:43.759',2,18);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (305,11,-88.33,'Auto-Pay','Cleared','2015-06-01T03:21:27.087',1,7);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (306,16,-60.83,'Debit','Cleared','2015-05-25T18:25:57.877',1,2);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (307,28,-87.75,'Debit','Cleared','2015-05-02T20:57:26.809',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (308,27,-66.71,'Debit','Cleared','2015-05-11T04:06:18.684',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (309,13,-25.13,'Debit','Cleared','2015-05-06T19:07:32.781',1,20);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (310,15,-20.8,'Debit','Cleared','2015-05-05T19:53:56.461',1,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (311,12,-67.88,'Debit','Cleared','2015-05-07T10:08:12.390',1,1);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (312,45,1500,'Deposit','Cleared','2015-05-03T07:18:29.398',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (313,19,-97.33,'Debit','Cleared','2015-05-12T08:01:23.042',1,15);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (314,22,-95.31,'Auto-Pay','Cleared','2015-05-08T00:25:06.645',1,3);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (315,49,-52.18,'Debit','Cleared','2015-05-08T12:32:19.610',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (316,24,-47.2,'Debit','Cleared','2015-05-07T16:45:38.650',1,16);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (317,23,-15.34,'Debit','Cleared','2015-05-30T08:27:41.572',2,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (318,43,-13.74,'Debit','Cleared','2015-05-26T18:24:47.156',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (319,18,-65.62,'Debit','Cleared','2015-05-01T23:17:41.971',1,4);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (320,12,-56.95,'Debit','Cleared','2015-05-29T11:54:33.945',1,1);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (321,43,-49.13,'Debit','Cleared','2015-05-20T01:58:50.164',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (322,10,-30.07,'Debit','Cleared','2015-05-12T05:39:31.914',1,17);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (323,44,-84.5,'Debit','Cleared','2015-05-17T00:48:35.688',1,4);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (324,26,-64.69,'Debit','Cleared','2015-05-02T10:42:38.849',1,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (325,27,-19.16,'Debit','Cleared','2015-05-12T04:38:27.928',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (326,49,-23.33,'Debit','Cleared','2015-05-29T04:04:27.788',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (327,39,-76.95,'Debit','Cleared','2015-05-13T15:30:57.510',1,15);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (328,43,-46.43,'Debit','Cleared','2015-05-08T22:58:00.564',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (329,15,-69.87,'Debit','Cleared','2015-05-29T16:30:39.442',1,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (330,45,1500,'Deposit','Cleared','2015-05-16T03:30:50.135',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (331,6,-57.74,'Debit','Cleared','2015-06-07T07:05:33.837',1,5);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (332,6,-76.84,'Debit','Cleared','2015-06-13T11:07:58.678',1,5);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (333,6,-102.36,'Debit','Cleared','2015-06-21T22:57:04.827',1,5);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (334,6,-99.82,'Debit','Cleared','2015-06-28T04:11:11.038',1,5);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (335,8,2000,'Credit','Cleared','2015-06-03T02:09:48.681',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (336,8,2000,'Credit','Cleared','2015-06-07T18:39:07.965',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (337,9,2000,'Credit','Cleared','2015-06-10T08:45:29.283',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (338,9,2000,'Credit','Cleared','2015-06-11T10:15:13.285',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (339,46,-27.16,'Debit','Cleared','2015-06-05T23:17:45.850',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (340,25,-19.49,'Debit','Cleared','2015-06-02T04:57:57.780',1,11);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (341,12,-13.02,'Debit','Cleared','2015-06-05T17:58:46.887',1,1);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (342,11,-95.39,'Auto-Pay','Cleared','2015-06-24T13:57:58.692',1,7);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (343,23,-49.78,'Debit','Cleared','2015-06-27T12:17:45.962',2,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (344,49,-92.44,'Debit','Cleared','2015-06-15T16:54:36.434',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (345,35,-56.17,'Debit','Cleared','2015-06-01T22:57:15.933',1,14);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (346,13,-19.25,'Debit','Cleared','2015-06-09T20:15:37.068',1,20);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (347,49,-94.44,'Debit','Cleared','2015-06-03T12:42:49.684',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (348,38,-56.17,'Debit','Cleared','2015-06-12T07:21:02.938',1,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (349,23,-69.7,'Debit','Cleared','2015-06-25T18:01:41.243',2,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (350,10,-58.62,'Debit','Cleared','2015-06-28T04:09:24.998',1,17);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (351,38,-28.73,'Debit','Cleared','2015-06-07T03:47:16.218',1,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (352,22,-77.88,'Auto-Pay','Cleared','2015-06-10T00:44:47.125',1,3);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (353,45,1500,'Deposit','Cleared','2015-06-09T15:45:32.617',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (354,15,-38.51,'Debit','Cleared','2015-06-17T16:01:15.301',1,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (355,39,-38.18,'Debit','Cleared','2015-06-08T19:44:32.525',1,15);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (356,47,-83.96,'Withdrawal','Cleared','2015-06-01T05:14:02.335',2,13);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (357,38,-78.12,'Debit','Cleared','2015-06-20T19:05:53.388',1,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (358,18,-83.29,'Debit','Cleared','2015-06-14T14:53:39.640',1,4);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (359,11,-59.48,'Auto-Pay','Cleared','2015-06-28T10:19:18.578',1,7);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (360,16,-5.53,'Debit','Cleared','2015-06-25T23:50:25.128',1,2);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (361,26,-32.87,'Debit','Cleared','2015-06-25T22:32:03.981',1,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (362,47,-19.77,'Withdrawal','Cleared','2015-06-07T05:09:33.691',2,13);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (363,16,-88.19,'Debit','Cleared','2015-06-17T05:52:53.203',1,2);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (364,25,-30.6,'Debit','Cleared','2015-06-16T20:30:53.660',1,11);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (365,19,-60.42,'Debit','Cleared','2015-06-03T12:59:29.436',1,15);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (366,12,-48.98,'Debit','Cleared','2015-06-10T18:46:11.081',1,1);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (367,12,-95.69,'Debit','Cleared','2015-06-29T01:41:05.964',1,1);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (368,18,-28.99,'Debit','Cleared','2015-06-14T13:28:05.442',1,4);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (369,46,-83.77,'Debit','Cleared','2015-06-20T07:57:39.454',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (370,14,-46.8,'Debit','Cleared','2015-06-03T10:13:58.796',1,6);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (371,25,-29.14,'Debit','Cleared','2015-06-22T18:38:16.403',1,11);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (372,44,-63.58,'Debit','Cleared','2015-06-16T02:36:50.254',1,4);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (373,21,-28.95,'Debit','Cleared','2015-06-26T11:33:10.502',1,12);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (374,19,-10.53,'Debit','Cleared','2015-06-03T21:26:16.613',1,15);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (375,21,-75.64,'Debit','Cleared','2015-06-11T16:01:23.317',1,12);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (376,32,-82.28,'Debit','Cleared','2015-06-13T06:27:04.760',2,18);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (377,44,-52.7,'Debit','Cleared','2015-06-23T14:02:53.473',1,4);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (378,22,-56.94,'Auto-Pay','Cleared','2015-06-21T19:26:05.170',1,3);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (379,12,-74.53,'Debit','Cleared','2015-06-23T19:41:34.688',1,1);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (380,18,-38.75,'Debit','Cleared','2015-06-29T07:38:45.760',1,4);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (381,47,-28.34,'Withdrawal','Cleared','2015-06-02T15:35:09.740',2,13);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (382,14,-57.99,'Debit','Cleared','2015-06-16T14:49:15.878',1,6);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (383,46,-16.42,'Debit','Cleared','2015-06-04T01:27:50.018',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (384,16,-51.09,'Debit','Cleared','2015-06-19T23:50:08.739',1,2);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (385,13,-76.85,'Debit','Cleared','2015-06-29T15:43:58.237',1,20);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (386,12,-43.67,'Debit','Cleared','2015-06-05T15:10:34.521',1,1);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (387,22,-30.5,'Auto-Pay','Cleared','2015-06-14T08:19:16.289',1,3);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (388,39,-34.82,'Debit','Cleared','2015-06-25T23:36:12.156',1,15);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (389,21,-20.24,'Debit','Cleared','2015-06-06T13:36:22.241',1,12);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (390,22,-7.53,'Auto-Pay','Cleared','2015-06-18T06:07:14.715',1,3);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (391,35,-86.26,'Debit','Cleared','2015-06-22T05:25:06.958',1,14);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (392,6,-104.32,'Debit','Cleared','2015-07-02T17:57:45.832',1,5);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (393,6,-106.3,'Debit','Cleared','2015-07-10T15:45:01.531',1,5);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (394,6,-64.78,'Debit','Cleared','2015-07-17T01:12:42.343',1,5);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (395,6,-92.55,'Debit','Cleared','2015-07-27T11:44:21.911',1,5);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (396,8,2000,'Credit','Cleared','2015-07-05T06:03:20.306',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (397,8,2000,'Credit','Cleared','2015-07-06T10:14:08.024',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (398,9,2000,'Credit','Cleared','2015-07-09T19:48:13.637',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (399,9,2000,'Credit','Cleared','2015-07-16T05:45:27.439',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (400,24,-13.15,'Debit','Cleared','2015-07-15T06:29:39.346',1,16);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (401,48,-12.97,'Debit','Cleared','2015-08-01T00:11:32.409',1,4);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (402,12,-7.03,'Debit','Cleared','2015-07-21T08:32:31.443',1,1);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (403,40,-88.93,'Auto-Pay','Cleared','2015-07-05T15:28:14.946',2,18);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (404,39,-64.39,'Debit','Cleared','2015-07-16T02:49:56.250',1,15);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (405,43,-25.91,'Debit','Cleared','2015-07-16T12:56:52.886',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (406,22,-42.19,'Auto-Pay','Cleared','2015-07-11T03:00:47.318',1,3);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (407,46,-46.77,'Debit','Cleared','2015-07-09T14:33:13.395',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (408,19,-71.3,'Debit','Cleared','2015-07-09T11:42:14.440',1,15);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (409,22,-10.25,'Auto-Pay','Cleared','2015-07-26T17:25:32.789',1,3);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (410,39,-70.51,'Debit','Cleared','2015-07-28T16:35:48.109',1,15);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (411,49,-29.8,'Debit','Cleared','2015-07-01T08:36:29.127',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (412,48,-32.93,'Debit','Cleared','2015-07-05T10:56:06.098',1,4);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (413,47,-52.08,'Withdrawal','Cleared','2015-07-31T04:36:06.793',2,13);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (414,15,-65.76,'Debit','Cleared','2015-07-12T16:19:00.249',1,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (415,48,-46.09,'Debit','Cleared','2015-07-02T10:29:47.590',1,4);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (416,32,-68.83,'Debit','Cleared','2015-07-30T04:18:02.894',2,18);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (417,12,-60.27,'Debit','Cleared','2015-07-04T21:21:20.883',1,1);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (418,20,-8.71,'Debit','Cleared','2015-07-30T21:38:04.127',1,14);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (419,29,-64.45,'Debit','Cleared','2015-07-03T23:26:11.828',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (420,10,-45.74,'Debit','Cleared','2015-07-21T03:13:46.361',1,17);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (421,43,-86.69,'Debit','Cleared','2015-07-15T02:47:02.359',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (422,22,-27.99,'Auto-Pay','Cleared','2015-07-07T07:51:09.265',1,3);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (423,44,-94.19,'Debit','Cleared','2015-07-05T13:30:41.739',1,4);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (424,29,-39.98,'Debit','Cleared','2015-07-21T02:17:17.652',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (425,20,-97.62,'Debit','Cleared','2015-07-02T14:59:55.824',1,14);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (426,45,1500,'Deposit','Cleared','2015-07-28T17:37:16.588',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (427,23,-9.38,'Debit','Cleared','2015-07-27T02:57:55.943',2,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (428,19,-65.46,'Debit','Cleared','2015-07-27T07:43:06.790',1,15);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (429,38,-5.28,'Debit','Cleared','2015-07-27T17:10:24.588',1,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (430,10,-56.73,'Debit','Cleared','2015-07-10T03:53:32.775',1,17);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (431,35,-12.49,'Debit','Cleared','2015-07-08T17:10:42.653',1,14);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (432,19,-43.61,'Debit','Cleared','2015-07-25T11:38:13.787',1,15);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (433,19,-45.25,'Debit','Cleared','2015-07-27T09:11:42.727',1,15);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (434,15,-26.41,'Debit','Cleared','2015-07-12T06:09:26.910',1,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (435,44,-51.21,'Debit','Cleared','2015-07-25T23:43:08.697',1,4);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (436,20,-87.56,'Debit','Cleared','2015-07-09T01:28:31.294',1,14);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (437,16,-72.72,'Debit','Cleared','2015-07-26T21:00:03.654',1,2);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (438,11,-45.08,'Auto-Pay','Cleared','2015-07-22T10:35:52.951',1,7);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (439,26,-52.26,'Debit','Cleared','2015-07-17T14:23:35.405',1,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (440,26,-55.31,'Debit','Cleared','2015-07-16T10:02:39.477',1,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (441,28,-26.86,'Debit','Cleared','2015-07-28T21:40:29.919',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (442,35,-87.97,'Debit','Cleared','2015-07-30T01:12:48.182',1,14);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (443,16,-14.39,'Debit','Cleared','2015-07-19T19:43:24.414',1,2);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (444,19,-11.2,'Debit','Cleared','2015-07-20T15:20:28.456',1,15);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (445,39,-29.53,'Debit','Cleared','2015-07-20T06:35:26.292',1,15);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (446,10,-67.98,'Debit','Cleared','2015-07-05T13:03:00.726',1,17);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (447,12,-20.9,'Debit','Cleared','2015-07-10T06:45:09.581',1,1);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (448,39,-47.08,'Debit','Cleared','2015-07-07T07:44:25.346',1,15);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (449,10,-15.75,'Debit','Cleared','2015-07-04T13:21:18.032',1,17);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (450,46,-55.25,'Debit','Cleared','2015-07-31T08:22:17.096',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (451,35,-55.24,'Debit','Cleared','2015-07-26T09:15:36.093',1,14);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (452,44,-41.01,'Debit','Cleared','2015-07-18T12:44:15.030',1,4);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (453,21,-89.7,'Debit','Cleared','2015-07-23T14:16:25.718',1,12);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (454,47,-6.79,'Withdrawal','Cleared','2015-07-09T08:57:45.096',2,13);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (455,10,-75.58,'Debit','Cleared','2015-07-20T17:51:43.292',1,17);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (456,16,-6.1,'Debit','Cleared','2015-07-12T15:51:16.540',1,2);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (457,12,-29.72,'Debit','Cleared','2015-07-29T19:45:01.270',1,1);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (458,32,-82.59,'Debit','Cleared','2015-07-28T04:46:59.078',2,18);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (459,26,-14.12,'Debit','Cleared','2015-07-16T01:32:28.318',1,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (460,21,-11.01,'Debit','Cleared','2015-07-21T13:41:28.711',1,12);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (461,16,-47.45,'Debit','Cleared','2015-07-30T16:10:40.643',1,2);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (462,38,-44.61,'Debit','Cleared','2015-07-20T01:43:09.159',1,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (463,11,-65.89,'Auto-Pay','Cleared','2015-07-12T09:35:33.805',1,7);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (464,6,-92.59,'Debit','Cleared','2015-08-04T12:06:43.691',1,5);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (465,6,-102.23,'Debit','Cleared','2015-08-13T10:16:51.830',1,5);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (466,6,-75.54,'Debit','Cleared','2015-08-20T15:10:37.134',1,5);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (467,6,-92.42,'Debit','Cleared','2015-08-24T20:49:39.632',1,5);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (468,8,2000,'Credit','Cleared','2015-08-06T20:53:55.708',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (469,8,2000,'Credit','Cleared','2015-08-09T22:16:27.905',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (470,9,2000,'Credit','Cleared','2015-08-06T16:47:11.472',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (471,9,2000,'Credit','Cleared','2015-08-09T21:55:08.451',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (472,19,-7.34,'Debit','Cleared','2015-08-25T21:05:50.328',1,15);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (473,47,-18.48,'Withdrawal','Cleared','2015-08-07T04:07:02.646',2,13);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (474,46,-86.64,'Debit','Cleared','2015-08-26T21:36:34.079',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (475,29,-76.26,'Debit','Cleared','2015-08-05T11:37:44.843',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (476,11,-50.31,'Auto-Pay','Cleared','2015-08-23T08:51:27.117',1,7);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (477,35,-53.58,'Debit','Cleared','2015-08-19T20:38:40.758',1,14);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (478,18,-27.08,'Debit','Cleared','2015-08-09T20:04:59.948',1,4);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (479,44,-76.32,'Debit','Cleared','2015-08-14T21:12:25.646',1,4);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (480,18,-36.68,'Debit','Cleared','2015-08-29T05:38:42.501',1,4);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (481,47,-19.16,'Withdrawal','Cleared','2015-08-14T14:24:50.128',2,13);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (482,35,-15.05,'Debit','Cleared','2015-08-17T08:10:03.012',1,14);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (483,22,-53.5,'Auto-Pay','Cleared','2015-08-01T09:13:15.423',1,3);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (484,49,-11.02,'Debit','Cleared','2015-08-26T19:35:41.934',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (485,43,-51.3,'Debit','Cleared','2015-08-20T18:35:52.219',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (486,28,-86.91,'Debit','Cleared','2015-08-19T16:12:16.273',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (487,44,-17.64,'Debit','Cleared','2015-08-14T07:10:34.863',1,4);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (488,38,-82.79,'Debit','Cleared','2015-08-26T22:00:14.424',1,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (489,20,-41.31,'Debit','Cleared','2015-08-20T00:40:12.247',1,14);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (490,26,-46.33,'Debit','Cleared','2015-08-13T18:16:45.203',1,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (491,38,-85.2,'Debit','Cleared','2015-08-22T22:47:39.535',1,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (492,10,-28.27,'Debit','Cleared','2015-08-11T10:17:47.611',1,17);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (493,23,-32.19,'Debit','Cleared','2015-08-13T01:23:02.748',2,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (494,28,-24.9,'Debit','Cleared','2015-08-09T02:44:44.356',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (495,23,-43.12,'Debit','Cleared','2015-08-14T01:13:57.590',2,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (496,26,-40.9,'Debit','Cleared','2015-08-04T11:15:07.386',1,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (497,11,-51.77,'Auto-Pay','Cleared','2015-08-24T03:22:02.277',1,7);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (498,27,-50.21,'Debit','Cleared','2015-08-13T15:22:39.130',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (499,28,-37.71,'Debit','Cleared','2015-08-20T02:01:20.890',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (500,47,-35.77,'Withdrawal','Cleared','2015-08-19T02:51:40.714',2,13);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (501,23,-76.21,'Debit','Cleared','2015-08-24T22:15:33.335',2,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (502,32,-88.35,'Debit','Cleared','2015-08-09T12:35:00.464',2,18);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (503,24,-95.83,'Debit','Cleared','2015-08-09T21:04:25.507',1,16);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (504,28,-42.72,'Debit','Cleared','2015-08-19T05:38:49.642',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (505,29,-50.24,'Debit','Cleared','2015-08-16T04:12:52.195',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (506,14,-78.25,'Debit','Cleared','2015-08-31T20:41:08.211',1,6);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (507,45,1500,'Deposit','Cleared','2015-08-25T01:12:09.028',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (508,46,-89.77,'Debit','Cleared','2015-08-05T12:29:32.234',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (509,25,-63.34,'Debit','Cleared','2015-08-24T13:19:01.668',1,11);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (510,35,-27.77,'Debit','Cleared','2015-08-03T13:39:39.090',1,14);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (511,35,-84.8,'Debit','Cleared','2015-08-07T19:07:30.423',1,14);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (512,21,-76.08,'Debit','Cleared','2015-08-15T17:30:02.367',1,12);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (513,13,-89.96,'Debit','Cleared','2015-08-31T06:03:58.961',1,20);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (514,46,-24.11,'Debit','Cleared','2015-08-14T22:32:19.197',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (515,22,-47.3,'Auto-Pay','Cleared','2015-08-25T18:26:39.654',1,3);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (516,10,-22.87,'Debit','Cleared','2015-08-07T19:07:50.134',1,17);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (517,15,-14.71,'Debit','Cleared','2015-08-20T19:48:40.517',1,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (518,46,-11.73,'Debit','Cleared','2015-08-06T01:21:15.023',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (519,48,-43.09,'Debit','Cleared','2015-08-10T22:52:17.742',1,4);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (520,12,-88.43,'Debit','Cleared','2015-08-09T14:53:21.410',1,1);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (521,24,-12.29,'Debit','Cleared','2015-08-08T06:57:32.018',1,16);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (522,29,-34.75,'Debit','Cleared','2015-08-09T03:38:37.828',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (523,47,-14.23,'Withdrawal','Cleared','2015-08-05T01:08:26.651',2,13);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (524,16,-33.79,'Debit','Cleared','2015-08-21T21:56:10.900',1,2);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (525,29,-75.96,'Debit','Cleared','2015-08-05T01:11:49.505',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (526,11,-41.97,'Auto-Pay','Cleared','2015-08-02T16:03:34.713',1,7);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (527,20,-11.32,'Debit','Cleared','2015-08-14T19:03:38.478',1,14);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (528,29,-70.77,'Debit','Cleared','2015-08-18T04:34:20.940',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (529,45,1500,'Deposit','Cleared','2015-08-08T17:54:16.740',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (530,13,-97.35,'Debit','Cleared','2015-08-21T23:53:58.020',1,20);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (531,35,-15.09,'Debit','Cleared','2015-08-25T04:31:18.480',1,14);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (532,16,-60.4,'Debit','Cleared','2015-08-29T16:05:04.382',1,2);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (533,45,1500,'Deposit','Cleared','2015-08-08T15:25:20.537',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (534,16,-39.04,'Debit','Cleared','2015-08-22T23:41:02.256',1,2);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (535,35,-63.24,'Debit','Cleared','2015-08-30T21:53:53.502',1,14);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (536,48,-56.54,'Debit','Cleared','2015-08-25T23:41:44.996',1,4);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (537,28,-5.86,'Debit','Cleared','2015-08-28T06:49:39.534',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (538,21,-69.07,'Debit','Cleared','2015-08-07T14:50:17.715',1,12);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (539,6,-67.16,'Debit','Cleared','2015-09-07T01:52:05.079',1,5);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (540,6,-105.37,'Debit','Cleared','2015-09-09T07:20:33.851',1,5);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (541,6,-56.94,'Debit','Cleared','2015-09-19T12:54:00.765',1,5);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (542,6,-74.9,'Debit','Cleared','2015-09-27T12:55:34.908',1,5);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (543,8,2000,'Credit','Cleared','2015-09-02T08:39:15.269',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (544,8,2000,'Credit','Cleared','2015-09-14T05:33:59.451',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (545,9,2000,'Credit','Cleared','2015-09-01T07:13:36.641',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (546,9,2000,'Credit','Cleared','2015-09-04T17:43:20.386',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (547,27,-25.3,'Debit','Cleared','2015-09-20T15:52:50.196',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (548,21,-23.1,'Debit','Cleared','2015-09-10T05:12:38.525',1,12);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (549,11,-14.95,'Auto-Pay','Cleared','2015-09-28T18:24:43.004',1,7);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (550,38,-42.48,'Debit','Cleared','2015-09-16T07:58:55.433',1,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (551,10,-24.32,'Debit','Cleared','2015-09-08T01:47:52.646',1,17);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (552,10,-44.15,'Debit','Cleared','2015-09-13T23:57:25.520',1,17);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (553,20,-11.74,'Debit','Cleared','2015-09-13T12:33:48.198',1,14);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (554,32,-5.99,'Debit','Cleared','2015-09-29T10:06:53.686',2,18);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (555,19,-94.93,'Debit','Cleared','2015-09-10T13:17:31.973',1,15);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (556,22,-6.76,'Auto-Pay','Cleared','2015-09-08T22:09:51.548',1,3);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (557,24,-47.37,'Debit','Cleared','2015-09-21T07:13:54.546',1,16);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (558,14,-46.6,'Debit','Cleared','2015-09-08T15:44:13.520',1,6);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (559,19,-96.86,'Debit','Cleared','2015-09-18T07:56:07.526',1,15);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (560,45,1500,'Deposit','Cleared','2015-09-03T12:45:47.159',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (561,13,-71.1,'Debit','Cleared','2015-09-05T11:41:25.573',1,20);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (562,23,-77.32,'Debit','Cleared','2015-09-20T07:52:50.996',2,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (563,18,-49.67,'Debit','Cleared','2015-09-11T05:14:12.123',1,4);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (564,20,-96.08,'Debit','Cleared','2015-09-17T05:07:47.920',1,14);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (565,10,-78.4,'Debit','Cleared','2015-09-14T04:00:15.982',1,17);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (566,18,-16.7,'Debit','Cleared','2015-09-04T07:02:33.740',1,4);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (567,25,-20.47,'Debit','Cleared','2015-09-03T13:50:59.602',1,11);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (568,10,-84.01,'Debit','Cleared','2015-09-18T06:42:51.801',1,17);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (569,47,-98.82,'Withdrawal','Cleared','2015-09-08T10:48:18.085',2,13);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (570,21,-66.49,'Debit','Cleared','2015-09-24T12:11:08.359',1,12);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (571,13,-91.92,'Debit','Cleared','2015-09-11T05:15:34.065',1,20);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (572,46,-86.32,'Debit','Cleared','2015-09-26T22:58:06.148',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (573,20,-53.22,'Debit','Cleared','2015-09-25T05:15:00.172',1,14);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (574,29,-52.41,'Debit','Cleared','2015-09-25T22:34:07.051',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (575,27,-67.71,'Debit','Cleared','2015-09-06T19:12:41.000',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (576,43,-83.21,'Debit','Cleared','2015-09-01T06:20:39.659',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (577,16,-71.6,'Debit','Cleared','2015-09-21T07:56:08.140',1,2);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (578,11,-26.71,'Auto-Pay','Cleared','2015-09-23T14:09:51.793',1,7);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (579,27,-41.16,'Debit','Cleared','2015-09-17T22:55:28.543',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (580,13,-83.29,'Debit','Cleared','2015-09-17T07:42:47.180',1,20);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (581,11,-40.53,'Auto-Pay','Cleared','2015-09-14T01:07:29.451',1,7);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (582,19,-44.49,'Debit','Cleared','2015-09-30T09:08:15.465',1,15);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (583,43,-33.92,'Debit','Cleared','2015-09-22T21:50:32.507',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (584,11,-22.75,'Auto-Pay','Cleared','2015-09-10T13:00:05.623',1,7);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (585,35,-54.84,'Debit','Cleared','2015-09-24T06:40:22.098',1,14);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (586,27,-28.03,'Debit','Cleared','2015-09-25T13:53:11.076',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (587,44,-69.52,'Debit','Cleared','2015-09-28T20:12:57.401',1,4);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (588,38,-16.31,'Debit','Cleared','2015-09-07T19:37:24.574',1,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (589,28,-36.35,'Debit','Cleared','2015-09-17T01:53:37.480',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (590,45,1500,'Deposit','Cleared','2015-09-26T14:27:50.031',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (591,21,-96.05,'Debit','Cleared','2015-09-09T08:11:32.350',1,12);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (592,20,-38.48,'Debit','Cleared','2015-09-20T14:12:03.826',1,14);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (593,47,-24.22,'Withdrawal','Cleared','2015-09-26T14:40:56.672',2,13);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (594,10,-85.62,'Debit','Cleared','2015-09-26T05:39:20.977',1,17);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (595,6,-69.31,'Debit','Cleared','2015-10-07T14:26:35.976',1,5);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (596,6,-90.07,'Debit','Cleared','2015-10-10T22:07:32.696',1,5);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (597,6,-105.86,'Debit','Cleared','2015-10-17T10:53:10.883',1,5);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (598,6,-80.5,'Debit','Cleared','2015-10-23T14:52:06.339',1,5);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (599,8,2000,'Credit','Cleared','2015-10-03T23:48:23.290',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (600,8,2000,'Credit','Cleared','2015-10-07T19:29:57.709',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (601,9,2000,'Credit','Cleared','2015-10-13T02:13:18.715',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (602,9,2000,'Credit','Cleared','2015-10-20T17:03:49.868',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (603,21,-52.71,'Debit','Cleared','2015-10-07T12:50:14.659',1,12);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (604,10,-31.76,'Debit','Cleared','2015-10-19T04:40:51.401',1,17);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (605,44,-56.35,'Debit','Cleared','2015-10-04T20:45:27.281',1,4);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (606,39,-12.61,'Debit','Cleared','2015-10-19T23:28:12.174',1,15);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (607,24,-46.31,'Debit','Cleared','2015-10-10T14:01:55.218',1,16);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (608,25,-31.79,'Debit','Cleared','2015-10-09T20:02:45.197',1,11);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (609,32,-88.64,'Debit','Cleared','2015-10-07T11:03:50.636',2,18);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (610,22,-62.13,'Auto-Pay','Cleared','2015-10-30T09:16:25.267',1,3);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (611,28,-6.83,'Debit','Cleared','2015-10-15T01:29:44.089',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (612,29,-24.57,'Debit','Cleared','2015-10-31T07:05:09.227',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (613,45,1500,'Deposit','Cleared','2015-10-23T18:00:34.505',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (614,10,-61.03,'Debit','Cleared','2015-10-07T23:23:03.079',1,17);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (615,13,-95.28,'Debit','Cleared','2015-10-13T14:57:38.396',1,20);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (616,43,-40.8,'Debit','Cleared','2015-10-10T21:04:59.147',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (617,29,-6.04,'Debit','Cleared','2015-10-06T12:18:46.501',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (618,12,-22.45,'Debit','Cleared','2015-10-13T14:10:35.040',1,1);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (619,11,-85.1,'Auto-Pay','Cleared','2015-10-06T23:51:33.183',1,7);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (620,49,-97.61,'Debit','Cleared','2015-10-11T23:36:11.216',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (621,48,-69.7,'Debit','Cleared','2015-10-27T00:02:49.372',1,4);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (622,10,-11.2,'Debit','Cleared','2015-10-18T12:50:03.605',1,17);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (623,35,-59.44,'Debit','Cleared','2015-10-26T00:01:14.562',1,14);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (624,48,-47.5,'Debit','Cleared','2015-10-11T10:51:08.850',1,4);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (625,19,-69.81,'Debit','Cleared','2015-10-23T11:10:22.909',1,15);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (626,10,-72.72,'Debit','Cleared','2015-10-25T18:37:14.813',1,17);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (627,49,-33.9,'Debit','Cleared','2015-10-12T10:55:27.613',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (628,47,-95.58,'Withdrawal','Cleared','2015-10-11T05:51:17.711',2,13);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (629,39,-56.63,'Debit','Cleared','2015-10-29T14:22:44.023',1,15);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (630,47,-19.43,'Withdrawal','Cleared','2015-10-23T23:16:27.364',2,13);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (631,26,-17.86,'Debit','Cleared','2015-10-05T07:18:48.006',1,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (632,20,-59.05,'Debit','Cleared','2015-10-29T13:28:53.687',1,14);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (633,29,-83.29,'Debit','Cleared','2015-10-27T19:08:39.174',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (634,29,-42.46,'Debit','Cleared','2015-10-13T23:18:24.432',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (635,44,-82.47,'Debit','Cleared','2015-10-19T14:21:31.651',1,4);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (636,10,-13.44,'Debit','Cleared','2015-10-14T17:41:10.615',1,17);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (637,46,-29.34,'Debit','Cleared','2015-10-18T06:28:10.957',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (638,18,-82.49,'Debit','Cleared','2015-10-08T06:51:47.946',1,4);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (639,20,-16.74,'Debit','Cleared','2015-10-24T18:43:52.446',1,14);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (640,13,-42.72,'Debit','Cleared','2015-10-28T20:35:21.515',1,20);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (641,40,-95.71,'Auto-Pay','Cleared','2015-10-17T21:34:52.764',2,18);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (642,46,-42.7,'Debit','Cleared','2015-10-30T04:15:22.770',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (643,46,-39.56,'Debit','Cleared','2015-10-22T03:04:52.464',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (644,49,-55.48,'Debit','Cleared','2015-10-07T06:19:54.931',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (645,40,-21.37,'Auto-Pay','Cleared','2015-10-08T16:19:21.269',2,18);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (646,18,-16.43,'Debit','Cleared','2015-10-09T01:36:29.912',1,4);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (647,6,-57.58,'Debit','Cleared','2015-11-05T05:02:17.159',1,5);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (648,6,-87.68,'Debit','Cleared','2015-11-12T13:17:49.671',1,5);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (649,6,-78.39,'Debit','Cleared','2015-11-19T15:42:53.701',1,5);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (650,6,-70.35,'Debit','Cleared','2015-11-27T00:31:27.800',1,5);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (651,8,2000,'Credit','Cleared','2015-11-02T09:53:22.307',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (652,8,2000,'Credit','Cleared','2015-11-04T14:23:25.969',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (653,9,2000,'Credit','Cleared','2015-11-06T14:40:45.585',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (654,9,2000,'Credit','Cleared','2015-11-13T21:10:21.723',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (655,16,-72.29,'Debit','Cleared','2015-11-16T01:08:57.654',1,2);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (656,11,-88.49,'Auto-Pay','Cleared','2015-11-26T17:28:47.893',1,7);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (657,40,-77.87,'Auto-Pay','Cleared','2015-11-06T13:50:13.063',2,18);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (658,45,1500,'Deposit','Cleared','2015-11-23T14:10:18.405',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (659,39,-75.02,'Debit','Cleared','2015-11-27T18:05:34.088',1,15);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (660,13,-90.36,'Debit','Cleared','2015-11-27T13:07:40.427',1,20);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (661,15,-10.27,'Debit','Cleared','2015-11-30T17:52:14.642',1,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (662,45,1500,'Deposit','Cleared','2015-11-05T02:18:24.679',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (663,24,-24.77,'Debit','Cleared','2015-11-16T04:16:28.308',1,16);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (664,39,-32.41,'Debit','Cleared','2015-11-23T21:15:49.677',1,15);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (665,47,-36.18,'Withdrawal','Cleared','2015-11-14T07:28:20.476',2,13);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (666,25,-59.48,'Debit','Cleared','2015-11-21T14:08:46.955',1,11);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (667,21,-47.8,'Debit','Cleared','2015-11-11T19:30:55.494',1,12);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (668,44,-49.74,'Debit','Cleared','2015-11-25T16:31:10.225',1,4);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (669,23,-54.72,'Debit','Cleared','2015-11-17T13:23:45.065',2,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (670,40,-54.39,'Auto-Pay','Cleared','2015-11-13T13:36:18.565',2,18);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (671,10,-53.13,'Debit','Cleared','2015-11-08T19:06:03.041',1,17);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (672,18,-73.22,'Debit','Cleared','2015-11-23T00:06:51.221',1,4);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (673,38,-41.03,'Debit','Cleared','2015-11-10T12:20:22.047',1,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (674,15,-84.17,'Debit','Cleared','2015-11-30T11:46:05.332',1,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (675,20,-15.93,'Debit','Cleared','2015-11-01T04:34:08.145',1,14);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (676,44,-51.03,'Debit','Cleared','2015-11-03T05:52:37.748',1,4);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (677,39,-21.18,'Debit','Cleared','2015-11-06T07:55:19.414',1,15);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (678,24,-38.99,'Debit','Cleared','2015-11-12T16:02:11.990',1,16);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (679,27,-73.8,'Debit','Cleared','2015-11-11T01:04:56.032',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (680,20,-29.02,'Debit','Cleared','2015-11-20T05:01:01.579',1,14);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (681,15,-14.09,'Debit','Cleared','2015-11-11T21:48:07.358',1,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (682,48,-82.66,'Debit','Cleared','2015-11-05T21:58:13.790',1,4);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (683,23,-40.01,'Debit','Cleared','2015-11-12T17:52:56.461',2,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (684,49,-83.59,'Debit','Cleared','2015-11-25T12:56:07.917',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (685,39,-53.27,'Debit','Cleared','2015-11-03T09:19:52.427',1,15);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (686,16,-29.58,'Debit','Cleared','2015-11-09T21:22:54.858',1,2);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (687,21,-24.51,'Debit','Cleared','2015-11-16T13:12:43.815',1,12);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (688,46,-59.54,'Debit','Cleared','2015-11-22T07:54:12.394',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (689,29,-23.88,'Debit','Cleared','2015-11-08T23:44:09.778',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (690,45,1500,'Deposit','Cleared','2015-11-23T16:14:43.795',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (691,11,-37.8,'Auto-Pay','Cleared','2015-11-19T04:39:27.712',1,7);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (692,38,-34.86,'Debit','Cleared','2015-11-16T15:56:01.210',1,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (693,38,-97.41,'Debit','Cleared','2015-11-02T14:12:31.927',1,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (694,22,-7.04,'Auto-Pay','Cleared','2015-11-10T21:50:45.333',1,3);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (695,48,-77.71,'Debit','Cleared','2015-11-23T08:13:18.108',1,4);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (696,23,-36.25,'Debit','Cleared','2015-11-01T22:47:34.042',2,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (697,39,-74.84,'Debit','Cleared','2015-11-23T07:21:08.279',1,15);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (698,22,-59.09,'Auto-Pay','Cleared','2015-11-27T23:38:54.933',1,3);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (699,38,-22.15,'Debit','Cleared','2015-11-05T10:31:06.115',1,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (700,18,-96.44,'Debit','Cleared','2015-11-15T03:57:08.033',1,4);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (701,29,-87.59,'Debit','Cleared','2015-11-01T14:11:49.926',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (702,20,-19.17,'Debit','Cleared','2015-11-20T11:39:26.391',1,14);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (703,46,-46.91,'Debit','Cleared','2015-11-07T02:46:09.087',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (704,24,-18.45,'Debit','Cleared','2015-11-22T21:56:40.826',1,16);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (705,15,-22.49,'Debit','Cleared','2015-11-19T03:22:01.220',1,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (706,6,-56.47,'Debit','Cleared','2015-12-07T04:32:03.450',1,5);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (707,6,-104.38,'Debit','Cleared','2015-12-10T15:40:14.680',1,5);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (708,6,-89.45,'Debit','Cleared','2015-12-20T23:58:27.352',1,5);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (709,6,-53.07,'Debit','Cleared','2015-12-27T16:25:09.185',1,5);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (710,8,2000,'Credit','Cleared','2015-12-14T07:36:32.315',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (711,8,2000,'Credit','Cleared','2015-12-14T22:08:12.923',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (712,9,2000,'Credit','Cleared','2015-12-14T17:02:13.771',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (713,9,2000,'Credit','Cleared','2015-12-27T19:20:52.589',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (714,46,-34.07,'Debit','Cleared','2015-12-09T13:18:03.145',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (715,21,-27.75,'Debit','Cleared','2015-12-13T05:32:40.673',1,12);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (716,18,-35.51,'Debit','Cleared','2015-12-02T14:28:41.426',1,4);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (717,15,-55.36,'Debit','Cleared','2015-12-31T10:38:10.221',1,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (718,13,-78.85,'Debit','Cleared','2015-12-11T04:42:52.964',1,20);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (719,29,-88.71,'Debit','Cleared','2015-12-29T09:06:10.512',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (720,23,-97.79,'Debit','Cleared','2015-12-26T11:56:20.725',2,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (721,43,-64.32,'Debit','Cleared','2015-12-22T15:36:10.480',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (722,23,-10.63,'Debit','Cleared','2015-12-05T00:00:43.459',2,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (723,15,-45.16,'Debit','Cleared','2015-12-28T13:14:34.388',1,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (724,14,-71.03,'Debit','Cleared','2015-12-05T09:03:28.694',1,6);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (725,40,-66.04,'Auto-Pay','Cleared','2015-12-08T00:11:15.544',2,18);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (726,47,-14.48,'Withdrawal','Cleared','2015-12-15T05:50:56.025',2,13);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (727,46,-42.5,'Debit','Cleared','2015-12-01T12:13:33.366',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (728,45,1500,'Deposit','Cleared','2015-12-25T07:57:22.983',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (729,47,-71.44,'Withdrawal','Cleared','2015-12-14T02:46:31.990',2,13);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (730,25,-41.12,'Debit','Cleared','2015-12-26T10:33:53.032',1,11);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (731,38,-93.16,'Debit','Cleared','2015-12-08T21:00:09.021',1,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (732,10,-7.84,'Debit','Cleared','2015-12-12T18:29:16.121',1,17);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (733,46,-94,'Debit','Cleared','2015-12-18T02:57:13.738',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (734,43,-95.37,'Debit','Cleared','2015-12-27T02:06:28.136',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (735,38,-24.91,'Debit','Cleared','2015-12-03T06:14:55.764',1,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (736,38,-94.3,'Debit','Cleared','2015-12-09T02:00:08.102',1,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (737,46,-37.97,'Debit','Cleared','2015-12-01T19:34:21.783',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (738,44,-80.11,'Debit','Cleared','2015-12-28T23:12:34.343',1,4);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (739,16,-56.43,'Debit','Cleared','2015-12-02T20:48:49.708',1,2);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (740,32,-63.94,'Debit','Cleared','2015-12-08T05:55:45.568',2,18);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (741,20,-60.29,'Debit','Cleared','2015-12-18T09:12:16.647',1,14);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (742,46,-78.5,'Debit','Cleared','2015-12-18T17:02:05.180',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (743,46,-17.78,'Debit','Cleared','2015-12-24T22:15:24.921',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (744,16,-55.34,'Debit','Cleared','2015-12-11T15:14:18.356',1,2);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (745,11,-71.56,'Auto-Pay','Cleared','2015-12-22T15:09:19.270',1,7);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (746,22,-13.58,'Auto-Pay','Cleared','2015-12-20T14:05:45.368',1,3);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (747,25,-76.5,'Debit','Cleared','2015-12-21T16:26:39.175',1,11);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (748,44,-80.49,'Debit','Cleared','2015-12-10T19:27:44.211',1,4);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (749,19,-63.35,'Debit','Cleared','2015-12-07T09:13:06.989',1,15);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (750,28,-56.28,'Debit','Cleared','2015-12-25T13:53:27.453',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (751,44,-78.31,'Debit','Cleared','2015-12-27T00:14:06.180',1,4);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (752,21,-35.65,'Debit','Cleared','2015-12-04T09:26:16.429',1,12);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (753,44,-98.48,'Debit','Cleared','2015-12-15T10:49:27.743',1,4);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (754,25,-53.13,'Debit','Cleared','2015-12-03T18:43:00.074',1,11);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (755,43,-12.88,'Debit','Cleared','2015-12-10T07:21:31.390',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (756,47,-25.12,'Withdrawal','Cleared','2015-12-24T00:02:01.620',2,13);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (757,29,-10.26,'Debit','Cleared','2015-12-22T06:00:11.633',1,10);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (758,23,-35.58,'Debit','Cleared','2015-12-25T20:19:03.153',2,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (759,15,-54.69,'Debit','Cleared','2015-12-28T02:56:14.836',1,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (760,45,1500,'Deposit','Cleared','2015-12-23T14:01:37.933',1,19);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (761,40,-78.32,'Auto-Pay','Cleared','2015-12-29T11:37:46.076',2,18);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (762,10,-32.94,'Debit','Cleared','2015-12-17T03:19:30.269',1,17);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (763,21,-27.09,'Debit','Cleared','2015-12-05T14:50:32.165',1,12);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (764,22,-95.28,'Auto-Pay','Cleared','2015-12-06T07:16:08.039',1,3);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (765,23,-87.56,'Debit','Cleared','2015-12-29T18:54:09.761',2,21);
INSERT INTO transactions (txid, payeeid, amount, txtype, txstatus, txdate, accountid, categoryid) VALUES (766,18,-70.1,'Debit','Cleared','2015-12-30T18:14:40.245',1,4);