package com.speedingplanet.banking.api;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.fasterxml.jackson.annotation.JsonProperty;
import org.joda.time.DateTime;

import javax.persistence.*;
import javax.validation.constraints.NotNull;

@SuppressWarnings("JpaQlInspection")
@Entity
@Table(name = "Transactions")
@NamedQueries({
    @NamedQuery(
        name = "com.speedingplanet.banking.api.Transaction.findAll",
        query = "SELECT tx from Transaction tx"
    )})
@NamedNativeQueries({
    @NamedNativeQuery(
        name = "com.speedingplanet.banking.api.Transaction.findByPayeeName",
        query = "SELECT * from TRANSACTIONS_PAYEES_CATEGORIES where payee = :payeeName",
        resultClass = Transaction.class
    )})
public class Transaction {

  public Transaction() {
  }

  public Transaction(int txId, DateTime txDate) {
    this.txId = txId;
    this.txDate = txDate;
  }

  public Transaction(int txId, int categoryId, int accountId, String txType,
                     int payeeId, String txStatus, DateTime txDate, double amount) {
    this.txId = txId;
    this.categoryId = categoryId;
    this.accountId = accountId;
    this.txType = txType;
    this.payeeId = payeeId;
    this.txStatus = txStatus;
    this.txDate = txDate;
    this.amount = amount;
  }

  @Id
  @GeneratedValue(strategy = GenerationType.IDENTITY)
  private int txId;

  @NotNull
  private int payeeId;

  @NotNull
  private double amount;

  @NotNull
  private String txType;
  private String txStatus;

  @JsonFormat
      (shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd'T'HH:mm:ss.SSS")
  private DateTime txDate;

  private int accountId;
  private int categoryId;

  public int getTxId() {
    return txId;
  }

  public int getPayeeId() {
    return payeeId;
  }

  public double getAmount() {
    return amount;
  }

  public String getTxType() {
    return txType;
  }

  public String getTxStatus() {
    return txStatus;
  }

  public DateTime getTxDate() {
    return txDate;
  }

  public int getAccountId() {
    return accountId;
  }

  public int getCategoryId() {
    return categoryId;
  }

  public void setPayeeId(int payeeId) {
    this.payeeId = payeeId;
  }

  public void setAmount(double amount) {
    this.amount = amount;
  }

  public void setTxStatus(String txStatus) {
    this.txStatus = txStatus;
  }

  public void setCategoryId(int categoryId) {
    this.categoryId = categoryId;
  }

  @Override
  public boolean equals(Object o) {
    if (this == o) return true;
    if (!(o instanceof Transaction)) return false;

    Transaction that = (Transaction) o;

    return this.getTxId() == that.getTxId();
  }

  @Override
  public int hashCode() {
    return txId;
  }
}
