package com.speedingplanet.banking.resources;

import com.google.common.base.Optional;
import com.speedingplanet.banking.api.Category;
import com.speedingplanet.banking.db.CategoryDAO;
import io.dropwizard.hibernate.UnitOfWork;

import javax.ws.rs.*;
import javax.ws.rs.core.*;
import java.util.List;

@Path("/category")
@Produces(MediaType.APPLICATION_JSON)
@Consumes(MediaType.APPLICATION_JSON)
public class CategoryResource {
  private final CategoryDAO categoryDAO;

  public CategoryResource(CategoryDAO categoryDAO) {
    this.categoryDAO = categoryDAO;
  }

  @GET
  @UnitOfWork
  public List<Category> getCategories(@DefaultValue("") @QueryParam("categoryName") String categoryName,
                                      @DefaultValue("") @QueryParam("categoryId") Integer categoryId) {
    List<Category> results = categoryDAO.query(categoryName, categoryId);
    if (results.size() == 0) {
      throw new NotFoundException(
          String.format("No records found for categoryName=[%s] and categoryId=[%s]", categoryName, categoryId));
    }
    return results;
  }

  @Path("/{categoryId:[0-9]+}")
  @GET
  @UnitOfWork
  public Category getCategory(@PathParam("categoryId") Integer categoryId) {
    Optional<Category> cat = Optional.fromNullable(categoryDAO.findById(categoryId));

    if (!cat.isPresent()) {
      throw new NotFoundException(String.format("Could not find Category with id %d.", categoryId));
    } else {
      return cat.get();
    }
  }

  @Path("/{categoryName:[A-z]+}")
  @GET
  @UnitOfWork
  public List<Category> getCategory(@PathParam("categoryName") String categoryName) {
    List<Category> results = categoryDAO.query(categoryName, 0);

    if (results.size() == 0) {
      throw new WebApplicationException(String.format("No records found for category name %s", categoryName), Response.Status.NOT_FOUND);
    }

    return results;
  }
}
