package com.speedingplanet.banking.resources;

import com.google.common.base.Optional;
import com.speedingplanet.banking.api.Payee;
import com.speedingplanet.banking.db.PayeeDAO;
import io.dropwizard.hibernate.UnitOfWork;

import javax.ws.rs.*;
import javax.ws.rs.core.Context;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.MultivaluedMap;
import javax.ws.rs.core.UriInfo;
import java.util.List;

@Path("/payee")
@Produces(MediaType.APPLICATION_JSON)
@Consumes(MediaType.APPLICATION_JSON)
public class PayeeResource {
  private final PayeeDAO payeeDAO;

  public PayeeResource(PayeeDAO payeeDAO) {
    this.payeeDAO = payeeDAO;
  }

  @GET
  @UnitOfWork
  public List<Payee> getPayees(@Context UriInfo uriInfo) {
    MultivaluedMap<String, String> queryParams = uriInfo.getQueryParameters();
    List<Payee> payees;

    if (queryParams.size() == 0) {
      payees = payeeDAO.findAll();
    } else {
      payees = payeeDAO.query(queryParams);
    }

    if (payees.size() == 0) {
      throw new NotFoundException("No Payees found for those search terms.");
    }
    return payees;
  }

  @Path("/{payeeId:[0-9]+}")
  @GET
  @UnitOfWork
  public Payee getPayee(@PathParam("payeeId") Integer payeeId) {
    Optional<Payee> p = Optional.fromNullable(payeeDAO.findById(payeeId));

    if (!p.isPresent()) {
      throw new NotFoundException(String.format("Could not find a Payee with id %d", payeeId));
    }

    return p.get();
  }
}
